About | Crotal
Author: user
Description: Write down your self-introduction at source/pages/About.markdown

# Crotal

A static site generator written in Python.

Home Archives Categories About RSS

## About

Write down your self-introduction at `source/pages/About.markdown`

comments powered by Disqus

#### About

A static site generator which is written in Python, super fast, easy to use, and free to all.Start a blog right now using Crotal!

#### Recent Posts

- Hello World!

© 2013 user | Powered by Crotal